/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.samza.clustermanager;

import java.util.ArrayList;
import java.util.List;

public class MockClusterResourceManagerCallback implements ClusterResourceManager.Callback {
  List<SamzaResource> resources = new ArrayList<>();
  List<SamzaResourceStatus> resourceStatuses = new ArrayList<>();
  Throwable error;

  @Override
  public void onResourcesAvailable(List<SamzaResource> resourceList) {
    resources.addAll(resourceList);
  }

  @Override
  public void onResourcesCompleted(List<SamzaResourceStatus> resourceStatusList) {
    resourceStatuses.addAll(resourceStatusList);
  }

  @Override
  public void onStreamProcessorLaunchSuccess(SamzaResource resource) {
    // no op
  }

  @Override
  public void onStreamProcessorLaunchFailure(SamzaResource resource, Throwable t) {
    // no op
  }

  @Override
  public void onError(Throwable e) {
    error = e;
  }
}
